==> haskell-hiedb-0.4.3.0-77-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hiedb.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hiedb
version:              0.4.3.0
visibility:           public
id:                   hiedb-0.4.3.0-1XFMJkkADhUFfgX10QtliR
key:                  hiedb-0.4.3.0-1XFMJkkADhUFfgX10QtliR
license:              BSD-3-Clause
copyright:            Zubin Duggal
maintainer:           zubin.duggal@gmail.com
author:               Zubin Duggal
synopsis:             Generates a references DB from .hie files
description:
    Tool and library to index and query a collection of `.hie` files

category:             Development
abi:                  9117ad05c726fac7d555371f3a571012
exposed:              True
exposed-modules:
    HieDb HieDb.Compat HieDb.Create HieDb.Dump HieDb.Html HieDb.Query
    HieDb.Run HieDb.Types HieDb.Utils

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hiedb-0.4.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hiedb-0.4.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hiedb-0.4.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hiedb
hs-libraries:         HShiedb-0.4.3.0-1XFMJkkADhUFfgX10QtliR
depends:
    algebraic-graphs-0.7-G5hgrf6WZL7KcnTYdaHiiq
    ansi-terminal-1.0.2-5q6RGAEXM9Iu4g3iI1aX2 array-0.5.4.0
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    directory-1.3.7.1 extra-1.7.16-80ecfHnnghTBG7BFI6ZuEu
    filepath-1.4.2.2 ghc-9.4.8
    hie-compat-0.3.1.1-EX7c63LZz6m3PpO1VmTjuM
    lucid-2.11.20230408-94lnXTtAjCd7AEff9njWkD mtl-2.2.2
    optparse-applicative-0.18.1.0-GDwWCLBUeEeIARGaJHYM6i
    sqlite-simple-0.4.19.0-LXK6XUJrj8e7nAvVZrwPIu
    terminal-size-0.3.4-G9QKE0nIH70HWdqrMvHn0A text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-hiedb/html/hiedb.haddock
haddock-html:         /usr/share/doc/haskell-hiedb/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hiedb-0.4.3.0-78-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hiedb.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hiedb
version:              0.4.3.0
visibility:           public
id:                   hiedb-0.4.3.0-A1ihZ3IufvmHM0KdmbU23p
key:                  hiedb-0.4.3.0-A1ihZ3IufvmHM0KdmbU23p
license:              BSD-3-Clause
copyright:            Zubin Duggal
maintainer:           zubin.duggal@gmail.com
author:               Zubin Duggal
synopsis:             Generates a references DB from .hie files
description:
    Tool and library to index and query a collection of `.hie` files

category:             Development
abi:                  990c4e1d806f6682d369dd20d7496b7f
exposed:              True
exposed-modules:
    HieDb HieDb.Compat HieDb.Create HieDb.Dump HieDb.Html HieDb.Query
    HieDb.Run HieDb.Types HieDb.Utils

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hiedb-0.4.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hiedb-0.4.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hiedb-0.4.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hiedb
hs-libraries:         HShiedb-0.4.3.0-A1ihZ3IufvmHM0KdmbU23p
depends:
    algebraic-graphs-0.7-KrC6xREe0U83I6X0X1QOGr
    ansi-terminal-1.0.2-GMfU0IJ80BpJLoxPRZMG7V array-0.5.4.0
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    directory-1.3.7.1 extra-1.7.16-LkdJ4kpBBKLHRRUCxLvq3e
    filepath-1.4.2.2 ghc-9.4.8
    hie-compat-0.3.1.1-EX7c63LZz6m3PpO1VmTjuM
    lucid-2.11.20230408-1Q8ut7shHXLIWJMnU6rX30 mtl-2.2.2
    optparse-applicative-0.18.1.0-iHmWlwYwvYAmLT692zZvc
    sqlite-simple-0.4.19.0-JxIpIwYCKYhEjCU5Sa3rNh
    terminal-size-0.3.4-G9QKE0nIH70HWdqrMvHn0A text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-hiedb/html/hiedb.haddock
haddock-html:         /usr/share/doc/haskell-hiedb/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
